@@ -1,6 +1,6 @@
 #############################################################################
 #
-# Copyright (c) 2009 Zope Corporation and Contributors.
+# Copyright (c) 2009 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -15,6 +15,6 @@
 # namespace package boilerplate
 try:
     __import__('pkg_resources').declare_namespace(__name__)
-except ImportError, e:
+except ImportError:
     from pkgutil import extend_path
     __path__ = extend_path(__path__, __name__)
