@@ -1,6 +1,6 @@
 #############################################################################
 #
-# Copyright (c) 2010 Zope Foundation and Contributors.
+# Copyright (c) 2010-2012 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -11,12 +11,11 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-import transaction
-
 import gocept.selenium.grok
 import gocept.selenium.grok.fixtures
-
 import gocept.selenium.tests.isolation
+import transaction
+
 
 test_layer = gocept.selenium.grok.Layer(gocept.selenium.grok)
 
@@ -26,22 +25,18 @@ class TestGrokTestCase(gocept.selenium.grok.TestCase):
     layer = test_layer
 
     def setUp(self):
-        super(TestGrokTestCase, self).setUp()
+        super().setUp()
         root = self.getRootFolder()
         root['app'] = gocept.selenium.grok.fixtures.App()
         transaction.commit()
 
-    def test_grok_layer(self):
-        layer = self.layer
-        self.assertTrue(layer.thread.is_alive())
-
     def test_grok_app(self):
         self.selenium.open('/app')
         self.selenium.assertTextPresent('Hello from grok')
 
 
 class GrokIsolation(gocept.selenium.tests.isolation.IsolationTests,
-    gocept.selenium.grok.TestCase):
+                    gocept.selenium.grok.TestCase):
 
     layer = test_layer
 
