@@ -12,23 +12,24 @@
 #
 ##############################################################################
 
-import gocept.httpserverlayer.plonetestingz2
-import gocept.selenium.base
+import gocept.httpserverlayer.plonetestingzope
+import gocept.selenium.webdriver
 import unittest
 
 
-class Layer(gocept.selenium.base.IntegrationBase,
-            gocept.httpserverlayer.plonetestingz2.Layer):
+class Layer(gocept.selenium.webdriver.IntegrationBase,
+            gocept.httpserverlayer.plonetestingzope.Layer):
     pass
 
 
 SELENIUM = Layer()
 
 
-class TestCase(gocept.selenium.base.TestCase, unittest.TestCase):
-    """NOTE: MRO requires gocept.selenium.base.TestCase to come first,
-    otherwise its setUp/tearDown is never called, since unittest.TestCase
-    does not call super().
+class TestCase(gocept.selenium.webdriver.WebdriverSeleneseTestCase,
+               unittest.TestCase):
+    """NOTE: MRO requires gocept.selenium.webdriver.WebdriverSeleneseTestCase
+    to come first, otherwise its setUp/tearDown is never called,
+    since unittest.TestCase does not call super().
     """
 
     @property
