@@ -1,21 +1,19 @@
 #!/usr/bin/env python
 """
-Convert HTML selenium tests to gocept.selenium based test cases.
+Convert HTML selenium tests to gocept.selenium.seleniumrcd test cases.
 """
 
-import re
-import os
-import glob
-from string import Template
 from optparse import OptionParser
-try:
-    from xml.etree import ElementTree as HTMLTreeBuilder
-except ImportError:
-    # Python < 2.5
-    from elementtree import HTMLTreeBuilder
+from string import Template
+from xml.etree import ElementTree as HTMLTreeBuilder
+from xml.etree.ElementTree import QName
+import glob
+import os
+import re
 
 
 module_template = Template('''\
+# -*- coding: $encoding -*-
 import unittest
 
 import gocept.selenium.plonetesting
@@ -32,7 +30,8 @@ def test_suite():
     return unittest.makeSuite(TestAll)
 ''')
 
-variable_regexp = re.compile('\$\{(?P<varname>\w*)\}')
+variable_regexp = re.compile(r'\$\{(?P<varname>\w*)\}')
+encoding_regexp = re.compile(r'charset=(.*)$')
 
 method_template = Template('''\
     def test_$testname(self):
@@ -52,14 +51,15 @@ def formatcommand(command, *args):
         matched = variable_regexp.match(arg)
         if matched is None:
             arguments.append('"%s"' % arg)
-        #XXX selenese should implement storeText
-        #else:
+        # XXX selenese should implement storeText
+        # else:
         #    arguments.append("self.getVar('%s')" % matched.group('varname'))
-    return '        selenium.%s(%s)' % (command, ', '.join(arguments))
+    return '        selenium.{}({})'.format(command, ', '.join(arguments))
 
 
 def make_parser():
-    parser = OptionParser(usage="converthtmltests -l LAYER [options] directory",
+    parser = OptionParser(
+        usage="converthtmltests -l LAYER [options] directory",
         version="%prog 1.0")
     parser.add_option("-f", "--file", dest="target",
                       default=DEFAULT_TARGET,
@@ -75,12 +75,14 @@ def make_parser():
                       help="do not print progress messages to stdout")
     return parser
 
+
 DEFAULT_TARGET = 'tests_all_selenium.py'
 LAYER_REQUIRED = 'Layer (-l) argument is required.'
 DIRECTORY_REQUIRED = 'Source directory is required.'
 LAYER_WITH_MODULE = 'Layer (-l) should include a module.'
 ONE_DIRECTORY = 'Only one source directory should be provided.'
 DIRECTORY_NOT_EXIST = 'Source directory does not exist.'
+XHTML_NAMESPACE = 'http://www.w3.org/1999/xhtml'
 
 
 def parse_options(parser, args=None):
@@ -103,11 +105,16 @@ def parse_options(parser, args=None):
 
 def parse_directory(directory, verbose):
     pattern = os.path.join(directory, '*.html')
+    prev_encoding = encoding = None
     for filename in glob.glob(pattern):
         if verbose:
-            print "Parsing [%s]" % filename
+            print("Parsing [%s]" % filename)
         filename = os.path.abspath(filename)
-        testname, commands = parse_file(filename)
+        testname, commands, encoding = parse_file(filename)
+        if encoding and prev_encoding is None:
+            prev_encoding = encoding
+            yield encoding
+        # XXX raise an error, if prev_encoding and encoding don't match
         if testname is None or len(commands) == 0:
             continue
         method = method_template.substitute(dict(
@@ -118,26 +125,36 @@ def parse_directory(directory, verbose):
 
 def parse_file(filename):
     tree = HTMLTreeBuilder.parse(filename)
-    root = tree.getroot()
 
     try:
-        testname = root.find('.//title').text
+        testname = tree.find('.//%s' % QName(XHTML_NAMESPACE, 'title')).text
     except AttributeError:
-        return None, None
+        return None, None, None
+    content_type = tree.find(".//%s" % QName(
+        XHTML_NAMESPACE, "meta[@http-equiv='Content-Type']")).get('content')
+    matched = encoding_regexp.search(content_type)
+    if matched is not None:
+        encoding = matched.group(1).lower()
+    else:
+        encoding = 'utf-8'
     commands = []
-    for row in root.findall('.//tbody/tr'):
-        command = formatcommand(*[td.text for td in row.findall('td')])
+    for row in tree.findall('.//{}/{}'.format(QName(XHTML_NAMESPACE, 'tbody'),
+                                              QName(XHTML_NAMESPACE, 'tr'))):
+        command = formatcommand(
+            *[td.text
+              for td in row.findall(str(QName(XHTML_NAMESPACE, 'td')))])
         commands.append(command)
-    return testname, commands
+    return testname, commands, encoding
 
 
-def make_module(methods, layer, layer_module):
+def make_module(methods, layer, layer_module, encoding):
     return module_template.substitute(dict(
         testname='all',
+        encoding=encoding,
         methods='\n'.join(methods),
         layer=layer,
         layer_module=layer_module,
-        ))
+    ))
 
 
 def main(args=None):
@@ -149,17 +166,22 @@ def main(args=None):
     layer_module = ".".join(layer.split('.')[:-1])
 
     methods = [method for method in parse_directory(directory, verbose)]
+    if methods:
+        encoding = methods.pop(0)
+    else:
+        encoding = 'utf-8'
 
     if len(methods) == 0:
-        print "No file was generated !"
+        print("No file was generated !")
         return
     if options.verbose:
-        print "Generating [%s]" % target
+        print("Generating [%s]" % target)
     f = open(target, 'wb')
-    module = make_module(methods, layer, layer_module)
+    module = make_module(methods, layer, layer_module, encoding)
+    module = module.encode(encoding)
     f.write(module)
     f.close()
 
 
-if  __name__ == '__main__':
+if __name__ == '__main__':
     main()
