@@ -13,11 +13,10 @@
 ##############################################################################
 
 # BBB
-from gocept.httpserverlayer.wsgi import FixupMiddleware as CleanerMiddleware
-
+from gocept.httpserverlayer.wsgi import FixupMiddleware as CleanerMiddleware  # noqa
 from wsgiref.simple_server import WSGIRequestHandler
 import gocept.httpserverlayer.wsgi
-import gocept.selenium.base
+import gocept.selenium.webdriver
 import os
 import unittest
 
@@ -30,7 +29,7 @@ class LogWSGIRequestHandler(WSGIRequestHandler):
             WSGIRequestHandler.log_request(self, *args)
 
 
-class Layer(gocept.selenium.base.IntegrationBase,
+class Layer(gocept.selenium.webdriver.IntegrationBase,
             gocept.httpserverlayer.wsgi.Layer):
 
     request_handler_class = LogWSGIRequestHandler
@@ -41,15 +40,13 @@ class Layer(gocept.selenium.base.IntegrationBase,
         # the testrunner distinguish between layers with different
         # applications.
         name += '.' + application.__class__.__name__
-        super(Layer, self).__init__(name=name, bases=bases)
+        super().__init__(name=name, bases=bases)
         self.wsgi_app = self.setup_wsgi_stack(application)
 
     def setup_wsgi_stack(self, app):
         return app
 
 
-class TestCase(gocept.selenium.base.TestCase, unittest.TestCase):
-    """NOTE: MRO requires gocept.selenium.base.TestCase to come first,
-    otherwise its setUp/tearDown is never called, since unittest.TestCase
-    does not call super().
-    """
+class TestCase(gocept.selenium.webdriver.WebdriverSeleneseTestCase,
+               unittest.TestCase):
+    """Webdriver test case with unittest assertions"""
